@@ -4,6 +4,7 @@ import re
 from collections import namedtuple
 from math import ceil
 from flask import request, make_response
+from datetime import datetime
 
 from . import ctx, json
 
@@ -113,15 +114,36 @@ def default_transform(fields=None):
     return transform
 
 
-def filter_expr(flt):
+def get_int_request_param(param_name):
+    value = request.values.get(param_name)
+    if value is None:
+        return None
+    try:
+        value = int(value)
+    except ValueError:
+        return None
+    return value
+
+
+def get_utcts_request_param(param_name):
+    ts = get_int_request_param(param_name)
+    if not ts:
+        return None
+    return datetime.utcfromtimestamp(ts)
+
+
+def filter_expr(flt, regexp=True):
     if flt.find(" ") >= 0:
         tokens = flt.split()
         return {"$in": tokens}
-    try:
-        return re.compile(flt, re.IGNORECASE)
-    # re.compile's can throw multiple different exceptions. We do not care what went wrong
-    except Exception:  # pylint: disable=broad-except
-        return ""
+    if regexp:
+        try:
+            return re.compile(flt, re.IGNORECASE)
+        # re.compile's can throw multiple different exceptions. We do not care what went wrong
+        except Exception:  # pylint: disable=broad-except
+            return ""
+    else:
+        return flt
 
 
 def arithmetic_expr(expr, try_int=True):
