@@ -1,5 +1,5 @@
 from flask.json import JSONEncoder
-from datetime import datetime
+from datetime import datetime, date
 from werkzeug.http import http_date
 from bson import ObjectId, Timestamp
 from .uorm.models.base_model import BaseModel
@@ -30,3 +30,9 @@ def dumps(o, default=default, **kwargs):
 def loads(text: str, **kwargs):
     return simplejson.loads(text, **kwargs)
 
+
+class GlasskitJSONEncoder(JSONEncoder):
+    def __init__(self, *args, **kwargs):
+        kwargs["default"] = default
+        super().__init__(*args, **kwargs)
+
