@@ -104,7 +104,7 @@ class StringField(TypedField):
     ):
         super().__init__(**kwargs)
         if auto_trim:
-            self.__class__.descriptor = AutotrimFieldDescriptor
+            self.descriptor = AutotrimFieldDescriptor
 
         if min_length is not None:
             assert isinstance(min_length, int)
